AttachmentBinary class

Attachment with binary data, typically encoded in BASE64.

Inheritance

Constructors

AttachmentBinary({String fmtType = 'application/octet-stream', String? encoding, required String value})
Creates a new binary attachment with the given format type, encoding, and value.

Properties

bytes Uint8List
The decoded bytes of the attachment.
no setter
encoding String?
The encoding type of the attachment, if any.
final
fmtType String
The MIME type of the attachment, defaults to 'application/octet-stream'.
finalinherited
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The raw value of the attachment, typically a base64 string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override