CalendarUserAddress class

Represents a calendar user address (CUA) with various parameters.

Constructors

CalendarUserAddress({required String address, String? cn, String? dir, String? sentby, String? language, CalendarUserType? cutype, String? cutypeName, List<String>? members, ParticipationRole? role, String? roleName, ParticipationStatus? partstat, String? partstatName, bool rsvp = false, List<String>? delegatedto, List<String>? delegatedfrom})
Creates a new calendar user address with the given parameters.
const

Properties

address String
The actual address, e.g., mailto:
final
cn String?
The common name (CN) parameter.
final
cutype CalendarUserType?
The calendar user type (CUTYPE) parameter.
final
cutypeName String?
The name of the calendar user type (CUTYPE) parameter.
final
delegatedfrom List<String>?
The delegated-from (DELEGATED-FROM) parameter, list of URIs.
final
delegatedto List<String>?
The delegated-to (DELEGATED-TO) parameter, list of URIs.
final
dir String?
The directory (DIR) parameter.
final
hashCode int
The hash code for this object.
no setteroverride
language String?
The language (LANGUAGE) parameter.
final
members List<String>?
The members (MEMBER) parameter, list of URIs.
final
partstat ParticipationStatus?
The participation status (PARTSTAT) parameter.
final
partstatName String?
The name of the participation status (PARTSTAT) parameter.
final
role ParticipationRole?
The participation role (ROLE) parameter.
final
roleName String?
The name of the participation role (ROLE) parameter.
final
rsvp bool
Whether a response is requested (RSVP) parameter, defaults to false.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sentby String?
The sent-by (SENT-BY) parameter.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override