TimeZoneSubComponent class
Represents a subcomponent of a timezone, such as a specific time zone rule.
- Inheritance
-
- Object
- CalendarComponent
- TimeZoneSubComponent
- Available extensions
Constructors
-
TimeZoneSubComponent({required String name, required Map<
String, List< properties, required List<PropertyValue> >CalendarComponent> components}) -
const
Properties
-
comments
→ List<
String> -
The comment associated with the time zone rule, if any.
no setter
-
components
→ List<
CalendarComponent> -
The nested components within this component.
finalinherited
- dtstart → CalDateTime
-
The date and time when the time zone rule starts. This is a required property.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isRecurring → bool
-
Available on TimeZoneSubComponent, provided by the TimeZoneSubComponentExtensions extension
Determines if the timezone component is recurring based on the presence of a recurrence rule (RRULE) or recurrence dates (RDATE).no setter - name → String
-
The name of the component, e.g., VCALENDAR, VEVENT, VTODO, etc.
finalinherited
-
properties
→ Map<
String, List< PropertyValue> > -
The properties of the component, mapped by property name to a list of values.
finalinherited
-
rdates
→ List<
RecurrenceDateTime> -
The list of recurrence dates associated with the time zone rule.
no setter
- rrule → RecurrenceRule?
-
The recurrence rule for the time zone rule, if any.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
tznames
→ List<
String> -
The list of time zone names associated with the time zone rule.
no setter
- tzoffsetFrom → UtcOffset
-
The time zone offset from which the rule applies. This is a required property.
no setter
- tzoffsetTo → UtcOffset
-
The time zone offset to which the rule applies. This is a required property.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
occurrences(
{CalDateTime? start, CalDateTime? end}) → Iterable< CalDateTime> -
Available on TimeZoneSubComponent, provided by the TimeZoneSubComponentExtensions extension
Generates all occurrences of the timezone component based on its recurrence rules, exclusions (EXDATE), and additional dates (RDATE). -
toIcsString(
{bool foldLines = true}) → String -
Available on CalendarComponent, provided by the CalendarComponentSerialization extension
Serializes this semantic component into iCalendar text. -
toString(
) → String -
A string representation of this object.
inherited
-
value<
T> (String name) → T -
Returns the first value for the given property name, or throws if not found.
inherited
-
valueOrNull<
T> (String name) → T? -
Returns the first value for the given property name, or null if not found.
inherited
-
values<
T> (String name) → List< T> -
Returns all values for the given property name, or an empty list if not found.
inherited
-
valuesUnion<
T> (String name) → List< T> -
Returns all values for the given property name, or an empty list if not found.
This flattens all values into a single list, useful for properties that can have
multiple values.
For example, CATEGORIES can have multiple values separated by commas.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited